// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import SwiftUI

struct OverviewEndedCourse: View {

    let endedDate: Date?

    var title: String {
        let dateString: String
        if let endedDate = endedDate {
            dateString = Self.dateFormatter.string(from: endedDate)
        } else {
            dateString = Localizable.common_missing_data()
        }
        return Localizable.overview_ended_title(dateString)
    }

    var body: some View {
        VStack {
            Image(R.image.illustrations.ended_course.name)
                .resizable()
                .frame(maxWidth: .infinity)
                .aspectRatio(contentMode: .fit)
            VStack {
                BasicCardView {
                    TitleTextVStack(
                        title: title,
                        titleStyle: .h4,
                        text: Localizable.overview_ended_description(),
                        textLineLimit: nil
                    )
                    .frame(maxWidth: .infinity)
                    .padding()
                }
                .padding(.bottom, 6)

                NavigationLink(
                    destination: DocumentationView(scrollToPersonalSection: true),
                    label: {
                        BasicCardView {
                            NavigationTitleVStack(
                                title: Localizable.overview_ended_data_title(),
                                titleStyle: .h4,
                                text: Localizable.overview_ended_data_description(),
                                textLineLimit: nil,
                                infoText: Localizable.overview_ended_data_go_to_settings_label()
                            )
                            .padding()
                        }
                    }
                )
            }
            .padding()
        }
    }
    private static var dateFormatter: DateFormatter = {
        let df = DateFormatter()
        df.dateStyle = .long
        df.timeStyle = .none
        return df
    }()
}

struct OverviewEndedCourse_Previews: PreviewProvider {
    static var previews: some View {
        ScrollView {
            OverviewEndedCourse(
                endedDate: Date()
            )
        }
    }
}
