// The MIT License
//
// Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
// of the Software, and to permit persons to whom the Software is furnished to do
// so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

import Foundation
import Combine
import SharedServices
import GMAppData
import ErrorData

public class CarePlanServiceMock: CarePlanService {

    public init() { }

    public func fetchCarePlan(maternityId: String) -> AnyPublisher<CarePlan, ServiceError> {
        let carePlan = CarePlan(
            patient: "patient",
            activities: (0...10).map({ i in
                let date = self.date(for: i)
                let status: Activity.Status = date.timeIntervalSinceNow <= 0 ? .finished : .planned
                return Activity(
                    practitioner: ActivityPractitioner(
                        healthCareActorsIdentification: nil,
                        firstName: "Test",
                        lastName: "Testsen",
                        organizationName: "Trifork",
                        phone: "88 88 88 88",
                        email: "info@trifork.com",
                        fax: nil
                    ),
                    location: ActivityLocation(
                        healthCareActorsIdentification: nil,
                        address: ActivityLocationAddress(street: "Europaplads 2", zip: "8000", city: "Aarhus C"),
                        organizationName: "Trifork",
                        phone: "88888888",
                        email: "info@trifork.com",
                        fax: nil
                    ),
                    scheduledString: "x+y",
                    plannedTime: ActivityPlannedTime(from: date, to: nil),
                    status: status,
                    ownership: nil,
                    title: "Title \(i)",
                    description: (0...20).map({ i in "text" }).joined(separator: " ").capitalized,
                    reference: nil,
                    code: nil,
                    kind: nil,
                    id: "\(i)",
                    careplanId: "123",
                    note: Note(
                        title: "Test note",
                        content: (0...50).map({ _ in "text" }).joined(separator: " ").capitalized,
                        date: randomDate(),
                        careplanId: "123",
                        enteredby: HealthCarePerformer(
                            person: Person(name: PersonName(prefixName: nil, firstNames: ["Test"], middleNames: nil, lastName: "Testsen")),
                            role: nil,
                            healthCareOrganization: nil,
                            healthCareOrganizationAdress: nil,
                            healthCareOrganizationPhoneNumber: nil
                        ),
                        documentUniqueId: nil,
                        version: nil,
                        dirty: nil
                    ),
                    observations: [
                        Observation(
                            dateOfMeasurement: randomDate(),
                            values: [
                                ObservationValues(value: "123", unit: "testers", name: "Fosterstilling")
                            ],
                            measuredBy: nil,
                            fetus: "Foster 1",
                            activityReference: nil,
                            type: .fetusPresentation,
                            id: "value-1",
                            version: nil
                        ),
                        Observation(
                            dateOfMeasurement: randomDate(),
                            values: [
                                ObservationValues(value: "321", unit: "testers", name: "Fosteraktivitet")
                            ],
                            measuredBy: nil,
                            fetus: "Foster 1",
                            activityReference: nil,
                            type: .fetusActivity,
                            id: "value-2",
                            version: nil
                        )
                    ],
                    sortDate: date
                )
            }),
            processId: nil,
            title: maternityId,
            description: nil,
            responsibleOrganization: CarePlanResponsibleOrganization(id: "organisation", source: "source"),
            id: "1",
            version: nil,
            documentStatus: nil
        )

        return MockPublisher.mockFailable(
            value: carePlan,
            error: ServiceError.networkError(.missingInternetConnection)
        )
    }

    private func date(for index: Int) -> Date {
        Date().addingTimeInterval(TimeInterval((index + Int.random(in: -100...100)) * 3600 * 24))
    }

    private func randomDate() -> Date {
        Date().addingTimeInterval(TimeInterval.random(in: -100...100) * 3600 * 24)
    }
}
